@@ -373,6 +373,7 @@ error:
 
 static enum lis_error lis_sane_get_device(struct lis_api *impl, const char *dev_id, struct lis_item **item)
 {
+	SANE_Status sane_err;
 	struct lis_sane_item *private;
 	enum lis_error err;
 	struct lis_sane *impl_private = LIS_SANE_PRIVATE(impl);
@@ -392,7 +393,12 @@ static enum lis_error lis_sane_get_device(struct lis_api *impl, const char *dev_
 	memcpy(&private->parent, &g_sane_item_template, sizeof(private->parent));
 
 	lis_log_debug("sane_open() ...")
-	err = sane_status_to_lis_error(sane_open(dev_id, &private->handle));
+	sane_err = sane_open(dev_id, &private->handle);
+	if (sane_err == SANE_STATUS_INVAL) {
+		err = LIS_ERR_OFFLINE;
+	} else {
+		err = sane_status_to_lis_error(sane_err);
+	}
 	lis_log_debug("sane_open(): 0x%X, %s", err, lis_strerror(err));
 	if (LIS_IS_ERROR(err)) {
 		free(private);
@@ -511,9 +517,15 @@ static enum lis_error lis_sane_item_get_scan_parameters(
 
 	memset(out_p, 0, sizeof(struct lis_scan_parameters));
 
+	lis_log_info(
+		"%s->sane_get_parameters() returned:"
+		" format=%d, height=%d, width=%d, bytes_per_line=%d, depth=%d",
+		private->item->parent.name,
+		p.format, p.lines, p.pixels_per_line, p.bytes_per_line, p.depth
+	)
 	out_p->width = p.pixels_per_line;
 	out_p->height = p.lines;
-	out_p->image_size = out_p->width * out_p->height;
+	out_p->image_size = p.bytes_per_line * p.lines;
 	/* ignore p.last_frame */
 
 	switch(p.format) {
@@ -526,7 +538,6 @@ static enum lis_error lis_sane_item_get_scan_parameters(
 			break;
 		case SANE_FRAME_RGB:
 			out_p->format = LIS_IMG_FORMAT_RAW_RGB_24;
-			out_p->image_size *= 3;
 			break;
 		case SANE_FRAME_RED:
 		case SANE_FRAME_GREEN:
@@ -803,13 +814,14 @@ static int lis_sane_check_opt_descriptor(const char *item_name, int opt_idx,
 
 failed:
 	lis_log_warning(
-		"Device [%s]: Invalid or unsupported option descriptor [%s](%d ; [%s] ; [%s])."
+		"Device [%s]: Invalid or unsupported option descriptor [%s](%d ; [%s] ; [%s] ; [%d])."
 		" Ignored",
 		item_name,
 		sane_desc->name != NULL ? sane_desc->name : "(null)",
 		opt_idx,
 		sane_desc->title != NULL ? sane_desc->title : "(null)",
-		sane_desc->desc != NULL ? sane_desc->desc : "(null)"
+		sane_desc->desc != NULL ? sane_desc->desc : "(null)",
+		sane_desc->type
 	);
 	return 0;
 }
@@ -1141,7 +1153,7 @@ static enum lis_error lis_sane_scan_start(struct lis_item *self,
 		"Sane: scan_start(): %d -> %d, %s",
 		sane_err, err, lis_strerror(err)
 	);
-	return sane_status_to_lis_error(sane_err);
+	return err;
 }
 
 
